==> qtjambi-charts-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiCharts/QAreaLegendMarker_shell.h <==
#ifndef QAREALEGENDMARKER_SHELL_H
#define QAREALEGENDMARKER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qarealegendmarker.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qareaseries.h>
#include <QtCharts/qlegend.h>
#include <QtCharts/qlegendmarker.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QAreaLegendMarker_shell : public QAreaLegendMarker, public QtJambiShellInterface
{
public:
    QAreaLegendMarker_shell(QAreaSeries* series0, QLegend* legend1, QObject* parent2 = nullptr);
    ~QAreaLegendMarker_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QAreaSeries* series() override;
    void timerEvent(QTimerEvent* event0) override;
    QLegendMarker::LegendMarkerType type() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAreaLegendMarker_access : public QAreaLegendMarker
{
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QAREALEGENDMARKER_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiCharts/QAreaLegendMarker_shell.h <==
#ifndef QAREALEGENDMARKER_SHELL_H
#define QAREALEGENDMARKER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qarealegendmarker.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qareaseries.h>
#include <QtCharts/qlegend.h>
#include <QtCharts/qlegendmarker.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QAreaLegendMarker_shell : public QAreaLegendMarker, public QtJambiShellInterface
{
public:
    QAreaLegendMarker_shell(QAreaSeries* series0, QLegend* legend1, QObject* parent2 = nullptr);
    ~QAreaLegendMarker_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QAreaLegendMarker_mshell;
    friend class QAreaLegendMarker_oshell;
};


class QAreaLegendMarker_mshell : public QAreaLegendMarker_shell
{
public:
    using QAreaLegendMarker_shell::QAreaLegendMarker_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAreaLegendMarker_oshell : public QAreaLegendMarker_mshell
{
public:
    using QAreaLegendMarker_mshell::QAreaLegendMarker_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QAreaSeries* series() override;
    void timerEvent(QTimerEvent* event0) override;
    QLegendMarker::LegendMarkerType type() override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAreaLegendMarker_access : public QAreaLegendMarker
{
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QAREALEGENDMARKER_SHELL_H
